@@ -92,9 +92,11 @@ def save(path: str, content: object, format: str = 'auto', encoding: str = 'utf-
 _decompress_formats = 'tar', 'zip', 'gzip', 'bzip2', 'rar', '7zip', 'lzma'
 def decompress(input_file: str, output_dir: str = None, format: str = 'auto') -> None:
 	''' Decompress the given file to the output directory regardless of its format. '''
-	output_dir = dirname(input_file) if output_dir is None else output_dir
+	if output_dir is None:
+		output_dir = dirname(input_file)
+	else:
+		makedirs(output_dir, exist_ok=True)
 	format = detect_format(input_file, format, accept=_decompress_formats)
-	makedirs(output_dir, exist_ok=True)
 	if format == 'zip':
 		from zipfile import ZipFile
 		with ZipFile(input_file, 'r') as i:
